@@ -33,7 +33,7 @@ from .widgets.video_display import VideoDisplay
 
 # UI Constants
 PANEL_SIZES = [200, 600, 300]  # Left, center, right panel widths
-JUMP_FRAMES = 10  # Frame jump amount for keyboard shortcuts
+JUMP_FRAMES = 50  # Frame jump amount for keyboard shortcuts
 
 
 class VideoAnnotator(QMainWindow):  # noqa: PLR0904
@@ -323,13 +323,17 @@ class VideoAnnotator(QMainWindow):  # noqa: PLR0904
         self.update_pupil_plot()
 
     def jump_forward_10(self) -> None:
-        """Jump forward 10 frames."""
-        self.video_manager.jump_frames(JUMP_FRAMES)
+        """Jump forward by configured amount of frames."""
+        config = self.config_service.get_config()
+        jump_amount = config.get_shift_jump_frames() if config else JUMP_FRAMES
+        self.video_manager.jump_frames(jump_amount)
         self.display_frame()
 
     def jump_backward_10(self) -> None:
-        """Jump backward 10 frames."""
-        self.video_manager.jump_frames(-JUMP_FRAMES)
+        """Jump backward by configured amount of frames."""
+        config = self.config_service.get_config()
+        jump_amount = config.get_shift_jump_frames() if config else JUMP_FRAMES
+        self.video_manager.jump_frames(-jump_amount)
         self.display_frame()
 
     def toggle_mute(self) -> None:
@@ -388,11 +392,6 @@ class VideoAnnotator(QMainWindow):  # noqa: PLR0904
 
         if successfully_imported > 0:
             self._load_project_videos()
-            QMessageBox.information(
-                self,
-                "Import Complete",
-                f"Successfully imported {successfully_imported} recordings.",
-            )
 
     def _show_project_dialog(self) -> None:
         """Show project selection dialog using project controller."""
