@@ -23,6 +23,7 @@ from PyQt6.QtWidgets import (
     QMessageBox,
     QPushButton,
     QScrollArea,
+    QSpinBox,
     QVBoxLayout,
     QWidget,
 )
@@ -102,7 +103,7 @@ class NewProjectDialog(BaseDialog):
         if self.existing_project_path:
             self._load_existing_project()
 
-    def setup_ui(self) -> None:  # noqa: PLR0914
+    def setup_ui(self) -> None:
         """Setup the new project creation UI."""
         layout = self.create_main_layout()
 
@@ -124,6 +125,14 @@ class NewProjectDialog(BaseDialog):
         self.project_name_input.setPlaceholderText("e.g., Museum Eye Tracking Study")
         project_form.addRow("Project Name:", self.project_name_input)
 
+        self.shift_jump_input = QSpinBox()
+        self.shift_jump_input.setMinimum(1)
+        self.shift_jump_input.setMaximum(1000)
+        self.shift_jump_input.setValue(50)
+        self.shift_jump_input.setSuffix(" frames")
+        self.shift_jump_input.setToolTip("Number of frames to jump when using Shift+Arrow keys")
+        project_form.addRow("Shift Jump Amount:", self.shift_jump_input)
+
         scroll_layout.addWidget(project_group)
 
         # Event Types
@@ -160,7 +169,7 @@ class NewProjectDialog(BaseDialog):
         layout.addWidget(scroll_area)
 
         # Buttons - text depends on create vs edit mode
-        button_text = "Save Project" if self.existing_project_path else "Create Project Configuration"
+        button_text = "Save" if self.existing_project_path else "Create Project Configuration"
         button_layout, buttons = self.create_button_layout(
             ("Cancel", self.close), (button_text, self.save_project), primary_button_idx=1
         )
@@ -249,7 +258,7 @@ class NewProjectDialog(BaseDialog):
         self.events_list.addItem(item)
         self.events_list.setItemWidget(item, item_widget)
 
-    def _edit_or_add_event(  # noqa: PLR0914
+    def _edit_or_add_event(
         self, item: QListWidgetItem = None, name_label: QLabel = None, color_box: QLabel = None
     ) -> None:
         """Single dialog for both editing existing events and adding new ones."""
@@ -443,6 +452,7 @@ class NewProjectDialog(BaseDialog):
             "project": {"name": self.project_name_input.text().strip()},
             "event_types": [],
             "default_color": [123, 171, 61],
+            "shift_jump_frames": self.shift_jump_input.value(),
         }
 
         # Add event types
@@ -513,6 +523,10 @@ class NewProjectDialog(BaseDialog):
                 project_name = config.get("project", {}).get("name", "")
                 self.project_name_input.setText(project_name)
 
+                # Load shift jump frames (default to 50 if not in config)
+                shift_jump_frames = config.get("shift_jump_frames", 50)
+                self.shift_jump_input.setValue(shift_jump_frames)
+
                 # Load event types and track original names
                 event_types = config.get("event_types", [])
                 for event_type in event_types:
@@ -664,7 +678,7 @@ class NewProjectDialog(BaseDialog):
         """Update a single CSV file with renames, deletions, and additions."""
         try:
             # Read the CSV file
-            with csv_file.open("r", newline="") as infile:
+            with csv_file.open("r", encoding="utf-8", newline="") as infile:
                 reader = csv.DictReader(infile)
                 rows = list(reader)
                 fieldnames = reader.fieldnames
